@@ -134,7 +134,10 @@ def get_cov(df):
     cuda.memcpy_htod(d_covariances, covariances)
 
     # Number of threads per block
-    threadCount = 1024
+    if rows >= 1024:
+        threadCount = 1024
+    else:
+        threadCount = rows
 
     # Number of blocks per grid
     blockCount = cols
@@ -155,7 +158,7 @@ def get_cov(df):
     cuda.memcpy_dtoh(covariances, d_covariances)
 
     # Return Covariance Matrix
-    return covariances.resize(cols, cols)
+    return covariances
 
 
 def hello():
